@@ -3,10 +3,11 @@
 import os
 import re
 import sys
+import warnings
 
 import config
 import localization as lang
-from config import (defaults, getcfg, geticon, get_argyll_display_number,
+from config import (defaults, enc, getcfg, geticon, get_argyll_display_number,
 					get_default_dpi, get_display_number, 
 					get_display_rects, scale_adjustment_factor, setcfg,
 					writecfg)
@@ -15,7 +16,7 @@ from log import safe_print
 from meta import name as appname
 from options import debug
 from util_list import floatlist, strlist
-from util_str import safe_unicode
+from util_str import safe_str, safe_unicode
 from wxaddons import wx
 from wxwindows import BaseApp, ConfirmDialog, InfoDialog, InvincibleFrame
 from wxfixes import GenBitmapButton as BitmapButton
@@ -23,8 +24,7 @@ try:
 	import RealDisplaySizeMM as RDSMM
 except ImportError, exception:
 	RDSMM = None
-	handle_error(u"Error - couldn't import RealDisplaySizeMM: " + 
-				 safe_unicode(exception), silent=True)
+	warnings.warn(safe_str(exception, enc), Warning)
 
 def get_default_size():
 	"""
@@ -126,6 +126,7 @@ class MeasureFrame(InvincibleFrame):
 		self.SetIcons(config.get_icon_bundle([256, 48, 32, 16], appname))
 		self.Bind(wx.EVT_CLOSE, self.close_handler, self)
 		self.Bind(wx.EVT_MOVE, self.move_handler, self)
+		self.Bind(wx.EVT_SET_FOCUS, self.focus_handler)
 		self.panel = wx.Panel(self, -1)
 		self.sizer = wx.GridSizer(3, 1, 0, 0)
 		self.panel.SetSizer(self.sizer)
@@ -472,6 +473,12 @@ class MeasureFrame(InvincibleFrame):
 				# Save Argyll display index to configuration
 				setcfg("display.number", n + 1)
 
+	def focus_handler(self, e):
+		e.Skip()
+		if e.EventObject == self:
+			# Need to give focus to the panel so controls can gain focus
+			self.panel.SetFocus()
+
 	def get_dimensions(self):
 		"""
 		Calculate and return the relative dimensions from the pixel values.
