@@ -155,6 +155,11 @@ if u"phoenix" in wx.PlatformInfo:
 	wx.DC.DrawRectangleRect = lambda dc, rect: dc.DrawRectangle(rect)
 	wx.DC.DrawRoundedRectangleRect = lambda dc, rect, radius: dc.DrawRoundedRectangle(rect, radius)
 	wx.DC.EndDrawing = lambda self: None
+	if not hasattr(wx.DC, "SetClippingRect"):
+		wx.DC.SetClippingRect = lambda dc, rect: dc.SetClippingRegion(rect.x,
+																	  rect.y,
+																	  rect.width,
+																	  rect.height)
 
 	wx.IconBundle.AddIconFromFile = lambda file, type=wx.BITMAP_TYPE_ANY: wx.IconBundle.AddIcon(file, type)
 
@@ -188,7 +193,12 @@ if u"phoenix" in wx.PlatformInfo:
 	wx.SystemSettings_GetFont = wx.SystemSettings.GetFont
 	wx.SystemSettings_GetMetric = wx.SystemSettings.GetMetric
 	wx.grid.EVT_GRID_CELL_CHANGE = wx.grid.EVT_GRID_CELL_CHANGED
-	wx.grid.Grid.wxGridSelectRows = wx.grid.Grid.GridSelectRows
+	if hasattr( wx.grid.Grid, "GridSelectRows"):
+		# wxPython Phoenix 4.0.0a
+		wx.grid.Grid.wxGridSelectRows = wx.grid.Grid.GridSelectRows
+	else:
+		# wxPython Phoenix 4.0.0b
+		wx.grid.Grid.wxGridSelectRows = wx.grid.Grid.SelectRows
 	wx.grid.PyGridCellEditor = wx.grid.GridCellEditor
 	wx.grid.PyGridCellRenderer = wx.grid.GridCellRenderer
 	wx.RegionFromBitmapColour = wx.Region
@@ -1295,6 +1305,9 @@ class PlateButton(platebtn.PlateButton):
 		bevt.SetString(self.GetLabel())
 		self.GetEventHandler().ProcessEvent(bevt)
 
+	def Update(self):
+		pass
+
 	Disable = ThemedGenButton.__dict__["Disable"]
 	Enable = ThemedGenButton.__dict__["Enable"]
 	Enabled = ThemedGenButton.__dict__["Enabled"]
